![pypi](https://img.shields.io/pypi/v/siterank.svg)
![python](https://img.shields.io/pypi/pyversions/siterank.svg)
![implementation](https://img.shields.io/pypi/implementation/siterank.svg)
<!-- https://img.shields.io/travis/prahladyeri/siterank/master.svg -->
![docs](https://readthedocs.org/projects/siterank/badge/?version=latest)
![license](https://img.shields.io/github/license/prahladyeri/siterank.svg)
![last-commit](https://img.shields.io/github/last-commit/prahladyeri/siterank.svg)
<!--![commit-activity](https://img.shields.io/github/commit-activity/w/prahladyeri/siterank.svg)-->
[![donate](https://img.shields.io/badge/-Donate-blue.svg?logo=paypal)](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=JM8FUXNFUK6EU)
[![follow](https://img.shields.io/twitter/follow/prahladyeri.svg?style=social)](https://twitter.com/prahladyeri)
# siterank
A python script to get alexa global rank for a given website or domain.

# Installation

	pip install siterank

# Usage

![screenshot](https://raw.githubusercontent.com/prahladyeri/siterank/master/screenshot.png)
